@@ -10,4 +10,10 @@ export const toggleFlag = 'jupyterlab_mutableai/settings:toggle-flag';
 
 export const updateSettings = 'jupyterlab_mutableai/settings:update-settings';
 
-export const processFile = 'context_menu:open';
+export const context_fast_forward = 'mutable-ai:prod';
+
+export const context_documentation = 'mutable-ai:doc';
+
+export const context_refactor = 'mutable-ai:refactor';
+
+export const context_custom = 'mutable-ai:custom';
