@@ -27,6 +27,7 @@ import {
 import { ToolbarManager } from './toolbarManager';
 import { requestAPI } from './handler';
 import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
+import { TransformPollingManager } from './transformPollingManager';
 
 enum mode {
   FULL = 'FULL',
@@ -35,6 +36,12 @@ enum mode {
   REFACTOR = 'REFACTOR'
 }
 
+interface IResponseModel {
+  message: string;
+  dirname: string;
+  uid: string;
+}
+
 export class MutableAIManager implements IMutableAI {
   constructor(options: IMutableAI.IOptions) {
     this.mutableAiMainMenu = null;
@@ -48,6 +55,7 @@ export class MutableAIManager implements IMutableAI {
     this.onDocToProduction = this.onDocToProduction.bind(this);
     this.onCustomCommand = this.onCustomCommand.bind(this);
     this.onRefactorToProduction = this.onRefactorToProduction.bind(this);
+    this.pollingCallback = this.pollingCallback.bind(this);
     this._toolbarManager = new ToolbarManager({
       docRegistry: options.docRegistry,
       handlers: {
@@ -71,6 +79,8 @@ export class MutableAIManager implements IMutableAI {
         console.warn(reason);
         this._ready.reject(reason);
       });
+
+    this._transformPollingManager = options.transformPollingManager;
   }
 
   /*
@@ -87,7 +97,14 @@ export class MutableAIManager implements IMutableAI {
     this._mutableAI?.set('enabled', false);
   }
 
-  private handleLunchToProductionCall(name: string) {
+  private pollingCallback(id: string, filename: string, dirname: string) {
+    this._transformPollingManager.startPolling(id, filename, dirname);
+  }
+
+  private handleLunchToProductionCall(
+    name: string,
+    callback: (id: string, filename: string, dirname: string) => void
+  ) {
     const apiKey = this._mutableAI?.get('apiKey').composite as string;
     const transformDomain = this._mutableAI?.get('transformDomain')
       .composite as string;
@@ -100,7 +117,10 @@ export class MutableAIManager implements IMutableAI {
     });
 
     reply
-      .then(response => console.log('Transformed Successfully!'))
+      .then((response: IResponseModel) => {
+        console.log('Transformed in progress!');
+        callback(response.uid, name, response.dirname);
+      })
       .catch(e => console.log('Transformation failed!', e));
   }
 
@@ -108,10 +128,13 @@ export class MutableAIManager implements IMutableAI {
     context: DocumentRegistry.IContext<INotebookModel>
   ) {
     const name = context.path;
-    this.handleLunchToProductionCall(name);
+    this.handleLunchToProductionCall(name, this.pollingCallback);
   }
 
-  private handleDocToProductionCall(name: string) {
+  private handleDocToProductionCall(
+    name: string,
+    callback: (id: string, filename: string, dirname: string) => void
+  ) {
     const apiKey = this._mutableAI?.get('apiKey').composite as string;
     const transformDomain = this._mutableAI?.get('transformDomain')
       .composite as string;
@@ -123,7 +146,10 @@ export class MutableAIManager implements IMutableAI {
     });
 
     reply
-      .then(response => console.log('Transformed doc Successfully!'))
+      .then((response: IResponseModel) => {
+        console.log('Transformed in progress!');
+        callback(response.uid, name, response.dirname);
+      })
       .catch(e => console.log('Transformation failed!', e));
   }
 
@@ -131,10 +157,13 @@ export class MutableAIManager implements IMutableAI {
     context: DocumentRegistry.IContext<INotebookModel>
   ) {
     const name = context.path;
-    this.handleRefactorToProductionCall(name);
+    this.handleRefactorToProductionCall(name, this.pollingCallback);
   }
 
-  private handleRefactorToProductionCall(name: string) {
+  private handleRefactorToProductionCall(
+    name: string,
+    callback: (id: string, filename: string, dirname: string) => void
+  ) {
     const apiKey = this._mutableAI?.get('apiKey').composite as string;
     const transformDomain = this._mutableAI?.get('transformDomain')
       .composite as string;
@@ -146,7 +175,10 @@ export class MutableAIManager implements IMutableAI {
     });
 
     reply
-      .then(response => console.log('Transformed doc Successfully!'))
+      .then((response: IResponseModel) => {
+        console.log('Transformed in progress!');
+        callback(response.uid, name, response.dirname);
+      })
       .catch(e => console.log('Transformation failed!', e));
   }
 
@@ -154,10 +186,13 @@ export class MutableAIManager implements IMutableAI {
     context: DocumentRegistry.IContext<INotebookModel>
   ) {
     const name = context.path;
-    this.handleDocToProductionCall(name);
+    this.handleDocToProductionCall(name, this.pollingCallback);
   }
 
-  private async handleCustomCommandCall(name: string) {
+  private async handleCustomCommandCall(
+    name: string,
+    callback: (id: string, filename: string, dirname: string) => void
+  ) {
     // Prompt the user about the statement to be executed
     const input = await InputDialog.getText({
       title: 'Mutable AI Custom Command',
@@ -187,14 +222,17 @@ export class MutableAIManager implements IMutableAI {
       });
 
       reply
-        .then(response => console.log('Transformed doc Successfully!'))
+        .then((response: IResponseModel) => {
+          console.log('Transformed in progress!');
+          callback(response.uid, name, response.dirname);
+        })
         .catch(e => console.log('Transformation failed!', e));
     }
   }
 
   private onCustomCommand(context: DocumentRegistry.IContext<INotebookModel>) {
     const name = context.path;
-    this.handleCustomCommandCall(name);
+    this.handleCustomCommandCall(name, this.pollingCallback);
   }
 
   private createContextMenu() {
@@ -209,7 +247,7 @@ export class MutableAIManager implements IMutableAI {
           ?.selectedItems()
           .next();
         if (file?.path) {
-          this.handleLunchToProductionCall(file.path);
+          this.handleLunchToProductionCall(file.path, this.pollingCallback);
         }
       }
     });
@@ -222,7 +260,7 @@ export class MutableAIManager implements IMutableAI {
           ?.selectedItems()
           .next();
         if (file?.path) {
-          this.handleDocToProductionCall(file.path);
+          this.handleDocToProductionCall(file.path, this.pollingCallback);
         }
       }
     });
@@ -235,7 +273,7 @@ export class MutableAIManager implements IMutableAI {
           ?.selectedItems()
           .next();
         if (file?.path) {
-          this.handleRefactorToProductionCall(file.path);
+          this.handleRefactorToProductionCall(file.path, this.pollingCallback);
         }
       }
     });
@@ -248,7 +286,7 @@ export class MutableAIManager implements IMutableAI {
           ?.selectedItems()
           .next();
         if (file?.path) {
-          this.handleCustomCommandCall(file.path);
+          this.handleCustomCommandCall(file.path, this.pollingCallback);
         }
       }
     });
@@ -341,4 +379,5 @@ export class MutableAIManager implements IMutableAI {
   private _docRef: IDisposable | undefined;
   private _customRef: IDisposable | undefined;
   private _refactorRef: IDisposable | undefined;
+  private _transformPollingManager: TransformPollingManager;
 }
