@@ -30,6 +30,9 @@ import {
   toggleFlag,
   updateSettings
 } from './commands';
+
+import { IDocumentManager } from '@jupyterlab/docmanager';
+import { TransformPollingManager } from './transformPollingManager';
 import { MutableAIManager } from './manager';
 
 const plugin: JupyterFrontEndPlugin<IMutableAI> = {
@@ -42,6 +45,7 @@ const plugin: JupyterFrontEndPlugin<IMutableAI> = {
     IMainMenu,
     ITranslator,
     INotebookTracker,
+    IDocumentManager,
     ICompletionManager
   ],
   activate: (
@@ -51,6 +55,7 @@ const plugin: JupyterFrontEndPlugin<IMutableAI> = {
     mainMenu: IMainMenu,
     translator: ITranslator,
     notebooks: INotebookTracker,
+    docManager: IDocumentManager,
     completionManager: ICompletionManager
   ): IMutableAI => {
     const { commands, contextMenu, docRegistry } = app;
@@ -58,6 +63,13 @@ const plugin: JupyterFrontEndPlugin<IMutableAI> = {
       Initialized main mutableAI manager object.
     */
 
+    const transformPollingManager = new TransformPollingManager({
+      docManager: docManager,
+      app,
+      getSettings: (): Promise<ISettingRegistry.ISettings> =>
+        settings.load(PLUGIN_ID)
+    });
+
     const manager = new MutableAIManager({
       translator,
       mainMenu,
@@ -66,7 +78,8 @@ const plugin: JupyterFrontEndPlugin<IMutableAI> = {
       factory,
       getSettings: (): Promise<ISettingRegistry.ISettings> =>
         settings.load(PLUGIN_ID),
-      docRegistry
+      docRegistry,
+      transformPollingManager
     });
 
     console.log('Mutable AI context menu is activated!');
@@ -133,34 +146,6 @@ const plugin: JupyterFrontEndPlugin<IMutableAI> = {
           }
         });
 
-        // /*
-        //   Mutable AI transform file in context menu command.
-        // */
-        // commands.addCommand(processFile, {
-        //   label: 'Fast Forward to Production with MutableAI',
-        //   caption: 'Mutable AI context menu.',
-        //   icon: fastForwardIcon,
-        //   execute: () => {
-        //     const file = factory.tracker.currentWidget?.selectedItems().next();
-        //     const apiKey = setting.get('apiKey').composite as string;
-        //     const transformDomain = setting.get('transformDomain')
-        //       .composite as string;
-
-        //     const dataToSend = { name: file?.path, apiKey, transformDomain };
-
-        //     // POST request
-        //     const reply = requestAPI<any>('TRANSFORM_NB', {
-        //       body: JSON.stringify(dataToSend),
-        //       method: 'POST'
-        //     });
-
-        //     // Log to console
-        //     reply
-        //       .then(response => console.log('Transformed Successfully!'))
-        //       .catch(e => console.log('Transformation failed!', e));
-        //   }
-        // });
-
         notebooks.widgetAdded.connect(
           (sender: INotebookTracker, panel: NotebookPanel) => {
             let editor = panel.content.activeCell?.editor ?? null;
