@@ -7,6 +7,7 @@ import { DocumentRegistry } from '@jupyterlab/docregistry';
 import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
 
 import { Token } from '@lumino/coreutils';
+import { TransformPollingManager } from './transformPollingManager';
 
 const BASE = 'jupyterlab_mutableai';
 
@@ -54,5 +55,7 @@ export namespace IMutableAI {
      * Extension settings getter
      */
     getSettings: () => Promise<ISettingRegistry.ISettings>;
+
+    transformPollingManager: TransformPollingManager;
   }
 }
